# coding: utf-8
# Copyright (c) 2015, 2018, Truelite Srl <info@truelite.it>
# Author: Mark Caglienzi <mark@truelite.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from django.contrib import admin, messages
from django.utils.translation import ugettext_lazy as _
import django_pettycash.models as dpcmodels


# refs #11832
# https://docs.djangoproject.com/en/1.11/ref/contrib/admin/#modeladmin-objects
# https://stackoverflow.com/a/9471632
class MonthlyBalanceAdmin(admin.ModelAdmin):
    fields = ('source', 'date', 'start')

    def has_change_permission(self, request, obj=None):
        if obj is not None and not obj.is_first():
            messages.error(request, _("You can edit only the first MonthlyBalance of a Source"))
            return False
        return super().has_change_permission(request, obj=obj)

    def has_delete_permission(self, request, obj=None):
        if obj is not None and obj.is_first():
            messages.error(request, _("You cannot delete the first MonthlyBalance of a Source"))
            return False
        return super().has_delete_permission(request, obj=obj)

    # # TODO: Find a better way to do this, even if the bottleneck won't be too much of a problem here
    # # This is maybe too much...so comment it, for now
    # def get_queryset(self, request):
        # first_monthlybalance_pks = []
        # # For every Source, get only the first MonthlyBalance
        # for source in dpcmodels.Source.objects.all():
            # mb = source.monthly_balances.order_by("date").first()
            # if mb: first_monthlybalance_pks.append(mb.pk)
        # qs = super().get_queryset(request)
        # qs = qs.filter(pk__in=first_monthlybalance_pks).order_by("date")
        # return qs


admin.site.register(dpcmodels.Source)
admin.site.register(dpcmodels.Tag)
admin.site.register(dpcmodels.Entry)
admin.site.register(dpcmodels.MonthlyBalance, MonthlyBalanceAdmin)
