# -*- coding: utf-8 -*-


from django.db import migrations, models
from django.conf import settings
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.COMPANY_MODEL),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Entry',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('kind', models.IntegerField(verbose_name='Type of the movement', choices=[(1, 'Inbound'), (2, 'Outbound')])),
                ('amount', models.DecimalField(verbose_name='Amount', decimal_places=2, max_digits=18, validators=[django.core.validators.MinValueValidator(0.01)])),
                ('reason', models.CharField(verbose_name='Reason', max_length=128)),
                ('date', models.DateField(verbose_name='Date')),
                ('created', models.DateTimeField(verbose_name='Date and time of creation', auto_now_add=True)),
                ('modified', models.DateTimeField(verbose_name='Date and time of last modification', auto_now=True)),
                ('note', models.CharField(verbose_name='Note', max_length=128, blank=True)),
                ('company', models.ForeignKey(verbose_name='Company', related_name='entries', null=True, to=settings.COMPANY_MODEL, blank=True)),
                ('created_by', models.ForeignKey(verbose_name='User that created the entry', related_name='created_entries', null=True, to=settings.AUTH_USER_MODEL, blank=True)),
                ('modified_by', models.ForeignKey(verbose_name='User that last modified the entry', related_name='modified_entries', null=True, to=settings.AUTH_USER_MODEL, blank=True)),
            ],
            options={
                'verbose_name_plural': 'entries',
                'ordering': ('date', 'pk'),
            },
        ),
        migrations.CreateModel(
            name='MonthlyBalance',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('date', models.DateField(verbose_name='First day of the month')),
                ('start', models.DecimalField(verbose_name='Beginning balance', max_digits=18, decimal_places=2)),
                ('end', models.DecimalField(verbose_name='Final balance', decimal_places=2, null=True, max_digits=18, blank=True)),
            ],
            options={
                'verbose_name_plural': 'monthly balances',
            },
        ),
        migrations.CreateModel(
            name='Source',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('name', models.CharField(verbose_name='Name of the source', max_length=64)),
                ('description', models.TextField(verbose_name='Description')),
            ],
            options={
                'verbose_name_plural': 'sources',
            },
        ),
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('name', models.CharField(verbose_name='Name of the tag', max_length=32)),
            ],
            options={
                'verbose_name_plural': 'tags',
            },
        ),
        migrations.AddField(
            model_name='monthlybalance',
            name='source',
            field=models.ForeignKey(verbose_name='Source', related_name='monthly_balances', to='django_pettycash.Source'),
        ),
        migrations.AddField(
            model_name='entry',
            name='source',
            field=models.ForeignKey(verbose_name='Source of the entry', related_name='entries', to='django_pettycash.Source'),
        ),
        migrations.AddField(
            model_name='entry',
            name='tags',
            field=models.ManyToManyField(verbose_name='Tags', related_name='entries', to='django_pettycash.Tag', blank=True),
        ),
    ]
