# coding: utf-8
# Copyright (c) 2015, Truelite Srl <info@truelite.it>
# Author: Mark Caglienzi <mark@truelite.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from django.conf.urls import url
from django.contrib.auth.decorators import login_required
from django_pettycash import views as dpcviews

# All django_pettycash view and url names will be prepended by dpc, to lessen the risk
# of name collisions with names in other applications.

urlpatterns = [
    # Entry CRUD
    url(r'^entry/list/(?P<month>[0-9][0-9][0-9][0-9]-[0-9][0-9])?$',
        login_required(dpcviews.DPCEntryListView.as_view()),
        name='dpc_entry_list'),

    url(r'^entry/list/csv/(?P<month>[0-9][0-9][0-9][0-9]-[0-9][0-9])?$',
        login_required(dpcviews.DPCEntryCSVListView.as_view()),
        name='dpc_entry_csv_list'),

    url(r'^entry/create$',
        login_required(dpcviews.DPCEntryCreateView.as_view()),
        name="dpc_entry_create"),

    url(r'^entry/update/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCEntryUpdateView.as_view()),
        name='dpc_entry_update'),

    url(r'^entry/delete/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCEntryDeleteView.as_view()),
        name='dpc_entry_delete'),

    url(r'^entry/detail/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCEntryDetailView.as_view()),
        name='dpc_entry_detail'),

    # refs #4782
    url(r'^entry/ajax/companies/$',
        login_required(dpcviews.DPCEntryCompanyListAjaxView.as_view()),
        name='dpc_entry_company_list_ajax'),

    # Source CRUD
    url(r'^source/list$',
        login_required(dpcviews.DPCSourceListView.as_view()),
        name='dpc_source_list'),

    url(r'^source/create$',
        login_required(dpcviews.DPCSourceCreateView.as_view()),
        name="dpc_source_create"),

    url(r'^source/update/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCSourceUpdateView.as_view()),
        name='dpc_source_update'),

    url(r'^source/delete/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCSourceDeleteView.as_view()),
        name='dpc_source_delete'),

    url(r'^source/detail/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCSourceDetailView.as_view()),
        name='dpc_source_detail'),

    # Tag CRUD
    url(r'^tag/list$',
        login_required(dpcviews.DPCTagListView.as_view()),
        name='dpc_tag_list'),

    url(r'^tag/create$',
        login_required(dpcviews.DPCTagCreateView.as_view()),
        name="dpc_tag_create"),

    url(r'^tag/update/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCTagUpdateView.as_view()),
        name='dpc_tag_update'),

    url(r'^tag/delete/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCTagDeleteView.as_view()),
        name='dpc_tag_delete'),

    url(r'^tag/detail/(?P<pk>[0-9]+)$',
        login_required(dpcviews.DPCTagDetailView.as_view()),
        name='dpc_tag_detail'),

    # Statistics views
    # refs #4921
    url(r'^statistics/balance/by_tag/$',
        login_required(dpcviews.DPCStatsBalanceByTag.as_view()),
        name='dpc_stats_balance_by_tag'),
]
